@@ -6,6 +6,7 @@ from plaid.api import (
     Auth,
     Categories,
     CreditDetails,
+    DepositSwitch,
     Holdings,
     Identity,
     Income,
@@ -17,6 +18,7 @@ from plaid.api import (
     Processor,
     Sandbox,
     Transactions,
+    Webhooks,
 )
 from plaid.requester import DEFAULT_TIMEOUT, post_request
 from plaid.utils import urljoin
@@ -78,6 +80,7 @@ class Client(object):
         self.Auth = Auth(self)
         self.Categories = Categories(self)
         self.CreditDetails = CreditDetails(self)
+        self.DepositSwitch = DepositSwitch(self)
         self.Holdings = Holdings(self)
         self.Identity = Identity(self)
         self.Income = Income(self)
@@ -89,6 +92,7 @@ class Client(object):
         self.Processor = Processor(self)
         self.Sandbox = Sandbox(self)
         self.Transactions = Transactions(self)
+        self.Webhooks = Webhooks(self)
 
     def post(self, path, data, is_json=True):
         '''Make a post request with client_id and secret key.'''
