@@ -24,4 +24,7 @@ def teardown_module(module):
 def test_get():
     client = create_client()
     response = client.Identity.get(access_token)
-    assert response['identity'] is not None
+    assert response['accounts'] is not None
+    for account in response['accounts']:
+        assert account['owners'] is not None
+        assert len(account['owners']) > 0
