@@ -10,6 +10,15 @@ from tests.integration.util import (
 )
 
 
+def test_create_token():
+    client = create_client()
+    # Just test the failure case - behavior here depends on the API keys used
+    with pytest.raises(InvalidRequestError) as e:
+        client.Processor.tokenCreate(
+            'fakeAccessToken', 'fakeAccountId', 'fakeProcessor')
+        assert e.code == 'INVALID_INPUT'
+
+
 def test_stripe_processor_token():
     client = create_client()
     # Just test the failure case - behavior here depends on the API keys used
